@@ -1,6 +1,6 @@
 package Sys::CmdMod::Plugin::Ionice;
 {
-  $Sys::CmdMod::Plugin::Ionice::VERSION = '0.17';
+  $Sys::CmdMod::Plugin::Ionice::VERSION = '0.18';
 }
 BEGIN {
   $Sys::CmdMod::Plugin::Ionice::AUTHORITY = 'cpan:TEX';
@@ -25,24 +25,13 @@ use File::Blarf;
 
 extends 'Sys::CmdMod::Plugin';
 
-has 'priority' => (
-    'is'       => 'rw',
-    'isa'      => 'Int',
-    'default' => 7,
-);
-
 has 'class' => (
     'is'       => 'rw',
     'isa'      => 'Int',
     'default' => 3,
 );
 
-has 'sysinfo' => (
-    'is'      => 'ro',
-    'isa'     => 'Linux::Inventory',
-    'lazy'    => 1,
-    'builder' => '_init_sysinfo',
-);
+sub _init_priority { return 7; }
 
 sub _init_binary {
     my $self = shift;
