@@ -1,6 +1,6 @@
 package Sys::CmdMod::Plugin::Nice;
 {
-  $Sys::CmdMod::Plugin::Nice::VERSION = '0.17';
+  $Sys::CmdMod::Plugin::Nice::VERSION = '0.18';
 }
 BEGIN {
   $Sys::CmdMod::Plugin::Nice::AUTHORITY = 'cpan:TEX';
@@ -20,12 +20,14 @@ use namespace::autoclean;
 
 extends 'Sys::CmdMod::Plugin';
 
-has 'priority' => (
+has 'niceness' => (
     'is'       => 'rw',
     'isa'      => 'Num',
     'default'  => 19,
 );
 
+sub _init_priority { return 10; }
+
 sub BUILD {
     my $self = shift;
 
@@ -43,7 +45,7 @@ sub _init_binary {
 sub cmd {
     my $self = shift;
     my $cmd  = shift;
-    return $self->binary() . ' -n ' . $self->priority() . q{ } . $cmd;
+    return $self->binary() . ' -n ' . $self->niceness() . q{ } . $cmd;
 }
 
 no Moose;
